![fsociety gif](fsociety.gif)

[comment]: # "TODO: Replace with fsociety gif in the same style"

# fsociety [![License](https://img.shields.io/badge/License-MIT-blue.svg?style=flat-square)](LICENSE) [![Python3](https://img.shields.io/badge/Python-3.7-orange.svg?style=flat-square)](https://www.python.org/download/releases/3.0/) [![Discord](https://img.shields.io/discord/541829295870443542?style=flat-square&color=%237289da)](https://discord.gg/BaBpuPn)

A Penetration Testing Framework

## Install

```bash
pip install fsociety
```

## Usage

```bash
fsociety
```

## Develop

```bash
git clone https://github.com/fsociety-team/fsociety.git
pip install -e ".[dev]"
```

## License

[MIT Licence](LICENSE)
